embassy-rp

Crates

git

Versions

rp235xa

Flavors

Blocking

Struct Blocking 

pub struct Blocking;
Blocking mode.

No interrupt is bound, completion is handled by polling or by an interrupt handler set up by the user.